@@ -1,14 +1,18 @@
 from url_matcher import Patterns
 
 from tests.po_lib import POBase
-from web_poet import handle_urls
+from web_poet import ItemPage, handle_urls
 
 
-class PONestedPkgOverriden:
+class PONestedPkgOverriden(ItemPage):
     ...
 
 
-@handle_urls(include=["example.com", "example.org"], exclude=["/*.jpg|"], overrides=PONestedPkgOverriden)
+@handle_urls(
+    include=["example.com", "example.org"],
+    exclude=["/*.jpg|"],
+    overrides=PONestedPkgOverriden,
+)
 class PONestedPkg(POBase):
     expected_overrides = PONestedPkgOverriden
     expected_patterns = Patterns(["example.com", "example.org"], ["/*.jpg|"])
